@@ -1,6 +1,6 @@
 package Map::Tube::London::Line::Bakerloo;
 
-$Map::Tube::London::Line::Bakerloo::VERSION   = '0.50';
+$Map::Tube::London::Line::Bakerloo::VERSION   = '0.51';
 $Map::Tube::London::Line::Bakerloo::AUTHORITY = 'cpan:MANWAR';
 
 use 5.006;
@@ -12,7 +12,7 @@ Map::Tube::London::Line::Bakerloo - London Tube Map Bakerloo Line stations.
 
 =head1 VERSION
 
-Version 0.50
+Version 0.51
 
 =head1 DESCRIPTION
 
@@ -54,7 +54,8 @@ London Tube Map Bakerloo Line stations.
 
 =over 2
 
-=item * The station "Oxford Circus" is also part of L<Central Line|Map::Tube::London::Line::Central>.
+=item * The station "Oxford Circus" is also part of L<Central Line|Map::Tube::London::Line::Central>
+        | L<Victoria Line|Map::Tube::London::Line::Victoria>.
 
 =item * The station "Paddington" is also part of L<Circle Line|Map::Tube::London::Line::Circle>
         | L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>.
